@@ -6,18 +6,23 @@ module.exports =
 
     async redirects() {
       return [
-        { source: "/", destination: "/docs/getting-started", permanent: false },
+        {
+          source: "/",
+          destination: "/docs/getting-started",
+          permanent: false,
+        },
         {
           source: "/install.sh",
           destination:
             "https://raw.githubusercontent.com/railwayapp/nixpacks/main/install.sh",
-            permanent: false,
+          permanent: false,
         },
         {
-            source: "/install.ps1",
-            destination: "https://raw.githubusercontent.com/railwayapp/nixpacks/main/install.ps1",
-            permanent: false,
-        }
+          source: "/install.ps1",
+          destination:
+            "https://raw.githubusercontent.com/railwayapp/nixpacks/main/install.ps1",
+          permanent: false,
+        },
       ];
     },
   });
