@@ -44,6 +44,7 @@ export const sidebarItems: ISidebarSection[] = [
       { href: "/docs/providers/deno", text: "Deno" },
       { href: "/docs/providers/elixir", text: "Elixir" },
       { href: "/docs/providers/fsharp", text: "F#" },
+      { href: "/docs/providers/gleam", text: "Gleam" },
       { href: "/docs/providers/go", text: "Go" },
       { href: "/docs/providers/haskell", text: "Haskell" },
       { href: "/docs/providers/java", text: "Java" },
@@ -53,6 +54,7 @@ export const sidebarItems: ISidebarSection[] = [
       { href: "/docs/providers/python", text: "Python" },
       { href: "/docs/providers/ruby", text: "Ruby" },
       { href: "/docs/providers/rust", text: "Rust" },
+      { href: "/docs/providers/scheme", text: "Scheme" },
       { href: "/docs/providers/staticfile", text: "Staticfile" },
       { href: "/docs/providers/swift", text: "Swift" },
       { href: "/docs/providers/scala", text: "Scala" },
@@ -63,9 +65,16 @@ export const sidebarItems: ISidebarSection[] = [
     text: "Deploying",
     links: [
       { text: "Railway", href: "/docs/deploying/railway" },
-      { text: "Flightcontrol", href: "/docs/deploying/flightcontrol" },
+      { text: "Coolify", href: "/docs/deploying/coolify" },
+      { text: "Dokku", href: "/docs/deploying/dokku" },
+      { text: "Dokploy", href: "/docs/deploying/dokploy" },
       { text: "Easypanel", href: "/docs/deploying/easypanel" },
-      { text: "Coherence", href: "/docs/deploying/coherence" },
+      { text: "Flightcontrol", href: "/docs/deploying/flightcontrol" },
+      { text: "GitHub Actions", href: "/docs/deploying/github-actions" },
+      { text: "PipeOps", href: "/docs/deploying/pipeops" },
+      { text: "Stacktape", href: "/docs/deploying/stacktape" },
+      { text: "JustDeploy", href: "/docs/deploying/justdeploy" },
+      { text: "ZaneOps", href: "/docs/deploying/zaneops" },
     ],
   },
 ];
