@@ -39,9 +39,10 @@ use providers::{
     fsharp::FSharpProvider, gleam::GleamProvider, go::GolangProvider,
     haskell::HaskellStackProvider, java::JavaProvider, lunatic::LunaticProvider,
     node::NodeProvider, php::PhpProvider, python::PythonProvider, ruby::RubyProvider,
-    rust::RustProvider, scala::ScalaProvider, staticfile::StaticfileProvider, swift::SwiftProvider,
-    zig::ZigProvider, Provider,
+    rust::RustProvider, scala::ScalaProvider, scheme::HauntProvider,
+    staticfile::StaticfileProvider, swift::SwiftProvider, zig::ZigProvider, Provider,
 };
+use std::process::Command;
 
 mod chain;
 #[macro_use]
@@ -49,7 +50,7 @@ pub mod nixpacks;
 pub mod providers;
 
 /// Supplies all currently-defined providers to build plan generators and image builders.
-pub fn get_providers() -> &'static [&'static (dyn Provider)] {
+pub fn get_providers() -> &'static [&'static dyn Provider] {
     &[
         &CrystalProvider {},
         &CSharpProvider {},
@@ -61,6 +62,7 @@ pub fn get_providers() -> &'static [&'static (dyn Provider)] {
         &GleamProvider {},
         &GolangProvider {},
         &HaskellStackProvider {},
+        &HauntProvider {},
         &JavaProvider {},
         &LunaticProvider {},
         &ScalaProvider {},
@@ -113,6 +115,7 @@ pub async fn create_docker_image(
     build_options: &DockerBuilderOptions,
 ) -> Result<()> {
     let app = App::new(path)?;
+
     let environment = Environment::from_envs(envs)?;
     let orig_path = app.source.clone();
 
@@ -152,9 +155,23 @@ pub async fn create_docker_image(
         std::process::exit(1);
     }
 
+    if build_options.out_dir.is_none() {
+        ensure_docker_exists()?;
+    }
+
     builder
         .create_image(app.source.to_str().unwrap(), &plan, &environment)
         .await?;
 
     Ok(())
 }
+
+fn ensure_docker_exists() -> Result<()> {
+    let mut docker_build_cmd = Command::new("docker");
+
+    if docker_build_cmd.output().is_err() {
+        bail!("Please install Docker to build the app https://docs.docker.com/engine/install/");
+    }
+
+    Ok(())
+}
