@@ -33,7 +33,6 @@ pub struct OutputDir {
 
 impl OutputDir {
     pub fn new(root: PathBuf, is_temp: bool) -> Result<Self> {
-        let root = root;
         let asset_root = PathBuf::from(NIXPACKS_OUTPUT_DIR);
 
         Ok(Self {
@@ -135,7 +134,7 @@ impl DockerfileGenerator for BuildPlan {
             String::new()
         } else {
             format!(
-                "RUN apt-get update && apt-get install -y --no-install-recommends {}",
+                "RUN sudo apt-get update && sudo apt-get install -y --no-install-recommends {}",
                 apt_pkgs.join(" ")
             )
         };
@@ -155,7 +154,7 @@ impl DockerfileGenerator for BuildPlan {
                 // Make the variables available at runtime
                 variables
                     .iter()
-                    .map(|var| format!("{}=${}", var.0, var.0))
+                    .map(|var| format!("{}=${}", var.0.trim(), var.0.trim()))
                     .collect::<Vec<_>>()
                     .join(" ")
             )
@@ -327,6 +326,14 @@ impl DockerfileGenerator for StartPhase {
             None => String::new(),
         };
 
+        let user_str = match &self.user {
+            Some(user) => formatdoc! {"
+                RUN useradd -m -s /bin/bash {user}
+                USER {user}
+            "},
+            None => String::new(),
+        };
+
         let dockerfile: String = match &self.run_image {
             Some(run_image) => {
                 let copy_cmds = utils::get_copy_from_commands(
@@ -344,20 +351,24 @@ impl DockerfileGenerator for StartPhase {
                   COPY --from=0 /etc/ssl/certs /etc/ssl/certs
                   RUN true
                   {copy_cmds}
+                  {user_str}
                   {start_cmd}
                 ",
                 run_image=run_image,
                 APP_DIR=APP_DIR,
                 copy_cmds=copy_cmds.join("\n"),
+                user_str=user_str,
                 start_cmd=start_cmd,}
             }
             None => {
                 formatdoc! {"
                   # start
                   COPY . /app
-                  {}
+                  {user_str}
+                  {start_cmd}
                 ",
-                start_cmd}
+                start_cmd=start_cmd,
+                user_str=user_str}
             }
         };
 
@@ -389,7 +400,7 @@ impl DockerfileGenerator for Phase {
         // Ensure paths are available in the environment
         let build_path = if let Some(paths) = &phase.paths {
             let joined_paths = paths.join(":");
-            format!("ENV NIXPACKS_PATH {joined_paths}:$NIXPACKS_PATH")
+            format!("ENV NIXPACKS_PATH={joined_paths}:$NIXPACKS_PATH")
         } else {
             String::new()
         };
@@ -467,13 +478,15 @@ impl DockerfileGenerator for Phase {
 
 #[cfg(test)]
 mod tests {
+    use std::collections::BTreeMap;
+
     use super::*;
 
     #[test]
     fn test_phase_generation() {
         let mut phase = Phase::new("test");
         phase.add_cmd("echo test");
-        phase.add_apt_pkgs(vec!["wget".to_owned()]);
+        phase.add_path("/test".to_string());
 
         let dockerfile = phase
             .generate_dockerfile(
@@ -485,12 +498,18 @@ mod tests {
             .unwrap();
 
         assert!(dockerfile.contains("echo test"));
+        assert!(dockerfile.contains("ENV NIXPACKS_PATH=/test:$NIXPACKS_PATH"));
     }
 
     #[test]
     fn test_plan_generation() {
         let mut plan = BuildPlan::default();
 
+        plan.add_variables(BTreeMap::from([(
+            "VAR1 ".to_string(),
+            "value1".to_string(),
+        )]));
+
         let mut test1 = Phase::new("test1");
         test1.add_cmd("echo test1");
         test1.add_apt_pkgs(vec!["wget".to_owned()]);
@@ -513,5 +532,6 @@ mod tests {
         assert!(dockerfile.contains("echo test2"));
         assert!(dockerfile.contains("apt-get update"));
         assert!(dockerfile.contains("wget"));
+        assert!(dockerfile.contains("ENV VAR1=$VAR1"));
     }
 }
