@@ -23,7 +23,7 @@ pub struct ShardYaml {
 pub struct CrystalProvider {}
 
 impl Provider for CrystalProvider {
-    fn name(&self) -> &str {
+    fn name(&self) -> &'static str {
         "crystal"
     }
 
@@ -41,7 +41,7 @@ impl Provider for CrystalProvider {
         let start = StartPhase::new(format!(
             "./bin/{}",
             target_names
-                .get(0)
+                .first()
                 .ok_or_else(|| anyhow::anyhow!("Unable to get executable name"))?
         ));
 
