@@ -19,7 +19,7 @@ const STACK_WORK_CACHE_DIR: &str = ".stack-work";
 pub struct HaskellStackProvider {}
 
 impl Provider for HaskellStackProvider {
-    fn name(&self) -> &str {
+    fn name(&self) -> &'static str {
         "haskell"
     }
 
@@ -62,7 +62,7 @@ impl Provider for HaskellStackProvider {
         let exe_names: Vec<String> = package.executables.keys().cloned().collect();
 
         let name = exe_names
-            .get(0)
+            .first()
             .ok_or_else(|| anyhow::anyhow!("Failed to get executable name"))?;
 
         let start = StartPhase::new(format!("/root/.local/bin/{name}"));
