@@ -14,10 +14,11 @@ use regex::Regex;
 pub struct JavaProvider {}
 
 const DEFAULT_JDK_VERSION: u32 = 17;
-const DEFAULT_GRADLE_VERSION: u32 = 7;
+const DEFAULT_GRADLE_VERSION: u32 = 8;
+const JAVA_NIXPKGS_ARCHIVE: &str = "59dc10b5a6f2a592af36375c68fda41246794b86";
 
 impl Provider for JavaProvider {
-    fn name(&self) -> &str {
+    fn name(&self) -> &'static str {
         "java"
     }
 
@@ -36,7 +37,8 @@ impl Provider for JavaProvider {
     fn get_build_plan(&self, app: &App, env: &Environment) -> Result<Option<BuildPlan>> {
         let (setup, build) = if self.is_using_gradle(app) {
             let pkgs = self.get_jdk_and_gradle_pkgs(app, env)?;
-            let setup = Phase::setup(Some(pkgs));
+            let mut setup = Phase::setup(Some(pkgs));
+            setup.set_nix_archive(JAVA_NIXPKGS_ARCHIVE.to_string());
 
             let mut build = Phase::build(None);
             let gradle_exe = self.get_gradle_exe(app);
@@ -46,7 +48,7 @@ impl Provider for JavaProvider {
                 build.add_cmd("chmod +x gradlew");
             }
 
-            build.add_cmd(format!("{gradle_exe} build -x check"));
+            build.add_cmd(format!("{gradle_exe} clean build -x check -x test"));
             build.add_cache_directory("/root/.gradle");
             build.depends_on_phase("setup");
 
@@ -55,7 +57,8 @@ impl Provider for JavaProvider {
             let jdk_version = self.get_jdk_version(app, env)?;
             let jdk_pkg = self.get_jdk_pkg(jdk_version)?;
 
-            let setup = Phase::setup(Some(vec![jdk_pkg, Pkg::new("maven")]));
+            let mut setup = Phase::setup(Some(vec![jdk_pkg, Pkg::new("maven")]));
+            setup.set_nix_archive(JAVA_NIXPKGS_ARCHIVE.to_string());
 
             let mvn_exe = self.get_maven_exe(app);
             let mut build = Phase::build(Some(format!("{mvn_exe} -DoutputFile=target/mvn-dependency-list.log -B -DskipTests clean dependency:list install"
@@ -94,10 +97,11 @@ impl JavaProvider {
     }
 
     fn get_start_cmd(&self, app: &App) -> Result<String> {
+        let build_gradle_content = self.read_build_gradle(app)?;
         let cmd = if self.is_using_gradle(app) {
             format!(
-                "java $JAVA_OPTS -jar {} build/libs/*.jar",
-                self.get_gradle_port_config(app)?
+                "java $JAVA_OPTS -jar {} $(ls -1 build/libs/*jar | grep -v plain)",
+                self.get_gradle_port_config(&build_gradle_content)
             )
         } else if app.includes_file("pom.xml") {
             format!(
@@ -115,27 +119,29 @@ impl JavaProvider {
         app.includes_file("gradlew")
     }
 
-    fn get_gradle_port_config(&self, app: &App) -> Result<String> {
-        let file_content = if app.includes_file("build.gradle") {
-            app.read_file("build.gradle")?
+    fn is_using_spring_boot(&self, build_gradle_content: &str) -> bool {
+        build_gradle_content.contains("org.springframework.boot:spring-boot")
+            || build_gradle_content.contains("spring-boot-gradle-plugin")
+            || build_gradle_content.contains("org.springframework.boot")
+            || build_gradle_content.contains("org.grails:grails-")
+    }
+
+    fn read_build_gradle(&self, app: &App) -> Result<String> {
+        if app.includes_file("build.gradle") {
+            app.read_file("build.gradle")
         } else if app.includes_file("build.gradle.kts") {
-            app.read_file("build.gradle.kts")?
+            app.read_file("build.gradle.kts")
         } else {
-            String::new()
-        };
+            Ok(String::new())
+        }
+    }
 
-        let is_spring_boot = file_content.contains("org.springframework.boot:spring-boot")
-            || file_content.contains("spring-boot-gradle-plugin")
-            || file_content.contains("org.springframework.boot")
-            || file_content.contains("org.grails:grails-");
-
-        let port_arg = if is_spring_boot {
+    fn get_gradle_port_config(&self, build_gradle_content: &str) -> String {
+        if self.is_using_spring_boot(build_gradle_content) {
             "-Dserver.port=$PORT".to_string()
         } else {
             String::new()
-        };
-
-        Ok(port_arg)
+        }
     }
 
     fn get_port_config(&self, app: &App) -> String {
@@ -164,6 +170,8 @@ impl JavaProvider {
 
     fn get_jdk_pkg(&self, jdk_version: u32) -> Result<Pkg> {
         let pkg = match jdk_version {
+            21 => Pkg::new("jdk21"),
+            20 => Pkg::new("jdk20"),
             19 => Pkg::new("jdk"),
             17 => Pkg::new("jdk17"),
             11 => Pkg::new("jdk11"),
@@ -176,7 +184,8 @@ impl JavaProvider {
 
     fn get_gradle_pkg(&self, gradle_version: u32) -> Result<Pkg> {
         let pkg = match gradle_version {
-            7 => Pkg::new("gradle"),
+            8 => Pkg::new("gradle"),
+            7 => Pkg::new("gradle_7"),
             6 => Pkg::new("gradle_6"),
             5 => Pkg::new("gradle_5"),
             4 => Pkg::new("gradle_4"),
@@ -217,7 +226,7 @@ impl JavaProvider {
         }
 
         let file_content = app.read_file("gradle/wrapper/gradle-wrapper.properties")?;
-        let custom_version = Regex::new(r#"(distributionUrl[\S].*[gradle])(-)([0-9|\.]*)"#)?
+        let custom_version = Regex::new(r"(distributionUrl[\S].*[gradle])(-)([0-9|\.]*)")?
             .captures(&file_content)
             .map(|c| c.get(3).unwrap().as_str().to_owned());
 
@@ -247,6 +256,80 @@ impl JavaProvider {
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_read_build_gradle_returns_with_content() {
+        let java = JavaProvider {};
+        let app = App::new("examples/java-gradle-8").unwrap();
+
+        let build_gradle_content = java.read_build_gradle(&app).unwrap();
+        let expcted_string = "mavenCentral";
+
+        assert!(build_gradle_content.contains(expcted_string));
+    }
+
+    #[test]
+    fn test_read_build_gradle_returns_with_content_from_kts_extension() {
+        let java = JavaProvider {};
+        let app = App::new("examples/java-gradle-8-kotlin").unwrap();
+
+        let build_gradle_content = java.read_build_gradle(&app).unwrap();
+        let expcted_string = "mavenCentral";
+
+        assert!(build_gradle_content.contains(expcted_string));
+    }
+
+    #[test]
+    fn test_read_build_gradle_returns_with_empty_string_if_build_gradle_is_not_found() {
+        let java = JavaProvider {};
+        let app = App::new("examples/java-maven").unwrap();
+
+        let build_gradle_content = java.read_build_gradle(&app).unwrap();
+
+        assert!(build_gradle_content.is_empty());
+    }
+
+    #[test]
+    fn test_is_using_spring_boot_returns_true() {
+        let java = JavaProvider {};
+        let spring_boot_identifiers = vec![
+            "org.springframework.boot:spring-boot",
+            "spring-boot-gradle-plugin",
+            "org.springframework.boot",
+            "org.grails:grails-",
+        ];
+
+        for spring_boot_identifier in spring_boot_identifiers {
+            assert!(java.is_using_spring_boot(spring_boot_identifier));
+        }
+    }
+
+    #[test]
+    fn test_is_using_spring_boot_returns_false() {
+        let java = JavaProvider {};
+
+        assert!(!java.is_using_spring_boot(""));
+    }
+
+    #[test]
+    fn test_get_start_cmd_returns_with_gradle_specific_command() {
+        let java = JavaProvider {};
+        let app = App::new("examples/java-gradle-hello-world").unwrap();
+
+        let expected_start_cmd =
+            String::from("java $JAVA_OPTS -jar  $(ls -1 build/libs/*jar | grep -v plain)");
+        assert_eq!(java.get_start_cmd(&app).unwrap(), expected_start_cmd);
+    }
+
+    #[test]
+    fn test_get_start_cmd_returns_with_maven_specific_command() {
+        let java = JavaProvider {};
+        let app = App::new("examples/java-maven").unwrap();
+
+        let expected_start_cmd =
+            String::from("java -Dserver.port=$PORT $JAVA_OPTS -jar target/*jar");
+        assert_eq!(java.get_start_cmd(&app).unwrap(), expected_start_cmd);
+    }
+
     #[test]
     fn test_get_jdk_pkg() {
         let java = JavaProvider {};
@@ -275,6 +358,42 @@ mod tests {
             .unwrap()
         );
 
+        assert_eq!(
+            Pkg::new("jdk21"),
+            java.get_jdk_pkg(
+                java.get_jdk_version(
+                    &App::new("examples/java-gradle-hello-world").unwrap(),
+                    &Environment::from_envs(vec!["NIXPACKS_JDK_VERSION=21"]).unwrap(),
+                )
+                .unwrap()
+            )
+            .unwrap()
+        );
+
+        assert_eq!(
+            Pkg::new("jdk20"),
+            java.get_jdk_pkg(
+                java.get_jdk_version(
+                    &App::new("examples/java-gradle-hello-world").unwrap(),
+                    &Environment::from_envs(vec!["NIXPACKS_JDK_VERSION=20"]).unwrap(),
+                )
+                .unwrap()
+            )
+            .unwrap()
+        );
+
+        assert_eq!(
+            Pkg::new("jdk"),
+            java.get_jdk_pkg(
+                java.get_jdk_version(
+                    &App::new("examples/java-gradle-hello-world").unwrap(),
+                    &Environment::from_envs(vec!["NIXPACKS_JDK_VERSION=19"]).unwrap(),
+                )
+                .unwrap()
+            )
+            .unwrap()
+        );
+
         assert_eq!(
             Pkg::new("jdk11"),
             java.get_jdk_pkg(
@@ -294,6 +413,18 @@ mod tests {
 
         assert_eq!(
             Pkg::new("gradle"),
+            java.get_gradle_pkg(
+                java.get_gradle_version(
+                    &App::new("examples/java-gradle-8").unwrap(),
+                    &Environment::from_envs(vec![]).unwrap(),
+                )
+                .unwrap()
+            )
+            .unwrap()
+        );
+
+        assert_eq!(
+            Pkg::new("gradle_7"),
             java.get_gradle_pkg(
                 java.get_gradle_version(
                     &App::new("examples/java-gradle-hello-world").unwrap(),
